@@ -32,7 +32,7 @@ from aucmedi.neural_network.architectures import architecture_dict, \
 #            Neural Network (model) class             #
 #-----------------------------------------------------#
 # Class which represents the Neural Network
-class Neural_Network:
+class NeuralNetwork:
     """ Neural Network class providing functionality for handling all model methods.
 
     This class is the third of the three pillars of AUCMEDI.
@@ -40,14 +40,14 @@ class Neural_Network:
     ??? info "Pillars of AUCMEDI"
         - [aucmedi.data_processing.io_data.input_interface][]
         - [aucmedi.data_processing.data_generator.DataGenerator][]
-        - [aucmedi.neural_network.model.Neural_Network][]
+        - [aucmedi.neural_network.model.NeuralNetwork][]
 
     With an initialized Neural Network model instance, it is possible to run training and predictions.
 
     ??? example "Example: How to use"
         ```python
         # Initialize model
-        model = Neural_Network(n_labels=8, channels=3, architecture="2D.ResNet50")
+        model = NeuralNetwork(n_labels=8, channels=3, architecture="2D.ResNet50")
         # Do some training
         datagen_train = DataGenerator(samples[:100], "images_dir/", labels=class_ohe[:100],
                                       resize=model.meta_input, standardize_mode=model.meta_standardize)
@@ -61,12 +61,12 @@ class Neural_Network:
     ??? example "Example: How to select an Architecture"
         ```python
         # 2D architecture
-        my_model_a = Neural_Network(n_labels=8, channels=3, architecture="2D.DenseNet121")
+        my_model_a = NeuralNetwork(n_labels=8, channels=3, architecture="2D.DenseNet121")
         # 3D architecture for multi-label classification (sigmoid activation)
-        my_model_b = Neural_Network(n_labels=8, channels=3, architecture="3D.ResNet50",
+        my_model_b = NeuralNetwork(n_labels=8, channels=3, architecture="3D.ResNet50",
                                     activation_output="sigmoid")
         # 2D architecture with custom input_shape
-        my_model_c = Neural_Network(n_labels=8, channels=3, architecture="2D.Xception",
+        my_model_c = NeuralNetwork(n_labels=8, channels=3, architecture="2D.Xception",
                                     input_shape=(512,512))
         ```
 
@@ -92,7 +92,7 @@ class Neural_Network:
         However, the recommended parameter are required for transfer learning.
 
         ```python title="Recommended way"
-        my_model = Neural_Network(n_labels=8, channels=3, architecture="2D.DenseNet121")
+        my_model = NeuralNetwork(n_labels=8, channels=3, architecture="2D.DenseNet121")
 
         my_dg = DataGenerator(samples, "images_dir/", labels=None,
                               resize=my_model.meta_input,                  # (224,224)
@@ -109,7 +109,7 @@ class Neural_Network:
                                                       channels=1,
                                                       input_shape=(128,128,128))
 
-        my_model = Neural_Network(n_labels=None, channels=None, architecture=my_arch)
+        my_model = NeuralNetwork(n_labels=None, channels=None, architecture=my_arch)
 
         from aucmedi.neural_network.architectures import supported_standardize_mode
         sf_norm = supported_standardize_mode["3D.DenseNet121"]
@@ -125,7 +125,7 @@ class Neural_Network:
 
         my_metadata = np.random.rand(len(samples), 10)
 
-        my_model = Neural_Network(n_labels=8, channels=3, architecture="2D.DenseNet121",
+        my_model = NeuralNetwork(n_labels=8, channels=3, architecture="2D.DenseNet121",
                                   meta_variables=10)
 
         my_dg = DataGenerator(samples, "images_dir/",
@@ -149,8 +149,9 @@ class Neural_Network:
                                                     If None is provided, the default input_shape for the architecture is selected
                                                     from the architecture dictionary.
             architecture (str or Architecture):     Key (str) or instance of a neural network model Architecture class instance.
-                                                    If a String is provided, the corresponding architecture is selected from the architecture dictionary.
-                                                    By default, a 2D Vanilla Model is used as Architecture.
+                                                    If a string is provided, the corresponding architecture is selected from the architecture dictionary.
+                                                    A string has to begin with either '3D.' or '2D' depending on the classification task.
+                                                    By default, a 2D Vanilla Model is used as architecture.
             pretrained_weights (bool):              Option whether to utilize pretrained weights e.g. from ImageNet.
             loss (Metric Function):                 The metric function which is used as loss for training.
                                                     Any Metric Function defined in Keras, in aucmedi.neural_network.loss_functions or any custom
@@ -161,7 +162,7 @@ class Neural_Network:
             activation_output (str):                Activation function which should be used in the classification head
                                                     ([Classifier][aucmedi.neural_network.architectures.classifier]).
                                                     Based on https://www.tensorflow.org/api_docs/python/tf/keras/activations.
-            fcl_dropout (bool):                     Option whether to utilize an additonal Dense & Dropout layer in the classification head
+            fcl_dropout (bool):                     Option whether to utilize an additional Dense & Dropout layer in the classification head
                                                     ([Classifier][aucmedi.neural_network.architectures.classifier]).
             meta_variables (int):                   Number of metadata variables, which should be included in the classification head.
                                                     If `None`is provided, no metadata integration block will be added to the classification head
@@ -268,24 +269,24 @@ class Neural_Network:
             However, in order to provide consistency with the single training without transfer learning,
             only a single history dictionary will be returned.
 
-            For differentiation prefixes are added infront of the corresponding logging keys:
+            For differentiation prefixes are added in front of the corresponding logging keys:
             ```
-            - History Start ->  prefix : tl     for "tansfer learning"
+            - History Start ->  prefix : tl     for "transfer learning"
             - History End   ->  prefix : ft     for "fine tuning"
             ```
 
         Args:
             training_generator (DataGenerator):     A data generator which will be used for training.
             validation_generator (DataGenerator):   A data generator which will be used for validation.
-            epochs (integer):                       Number of epochs. A single epoch is defined as one iteration through
+            epochs (int):                           Number of epochs. A single epoch is defined as one iteration through
                                                     the complete data set.
-            iterations (integer):                   Number of iterations (batches) in a single epoch.
+            iterations (int):                       Number of iterations (batches) in a single epoch.
             callbacks (list of Callback classes):   A list of Callback classes for custom evaluation.
             class_weights (dictionary or list):     A list or dictionary of float values to handle class unbalance.
-            transfer_learning (boolean):            Option whether a transfer learning training should be performed.
+            transfer_learning (bool):               Option whether a transfer learning training should be performed. If true, a minimum of 5 epochs will be trained.
 
         Returns:
-            history (dictionary):                   A history dictionary from a Keras history object which contains several logs.
+            history (dict):                   A history dictionary from a Keras history object which contains several logs.
         """
         # Running a standard training process
         if not transfer_learning:
@@ -344,7 +345,7 @@ class Neural_Network:
                                          max_queue_size=self.batch_queue_size,
                                          verbose=self.verbose)
             # Combine logged history objects
-            hs = {"tl_" + k: v for k, v in history_start.history.items()}       # prefix : tl for tansfer learning
+            hs = {"tl_" + k: v for k, v in history_start.history.items()}       # prefix : tl for transfer learning
             he = {"ft_" + k: v for k, v in history_end.history.items()}         # prefix : ft for fine tuning
             history = {**hs, **he}
             # Return combined history objects
@@ -379,7 +380,7 @@ class Neural_Network:
     def reset_weights(self):
         """ Re-initialize weights of the neural network model.
 
-        Useful for training multiple models with the same Neural_Network object.
+        Useful for training multiple models with the same NeuralNetwork object.
         """
         self.model.set_weights(self.initialization_weights)
 
